@@ -12,36 +12,10 @@ use Getopt::Long qw(2.36 GetOptionsFromArray);
 use Pod::Usage;
 use Carp;
 
-=head1 NAME
 
-App::Countdown - wait some specified time while displaying the remaining time.
-
-=head1 VERSION
-
-Version 0.4.4
-
-=cut
-
-our $VERSION = '0.4.4';
+our $VERSION = '0.4.5';
 
 
-=head1 SYNOPSIS
-
-    use App::Countdown;
-
-    App::Countdown->new({ argv => [@ARGV] })->run();
-
-=head1 SUBROUTINES/METHODS
-
-=head2 new
-
-A constructor. Accepts the argv named arguments.
-
-=head2 run
-
-Runs the program.
-
-=cut
 
 sub new
 {
@@ -184,6 +158,43 @@ sub run
 
 1;
 
+
+1; # End of App::Countdown
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+App::Countdown - wait some specified time while displaying the remaining time.
+
+=head1 VERSION
+
+version 0.4.5
+
+=head1 SYNOPSIS
+
+    use App::Countdown;
+
+    App::Countdown->new({ argv => [@ARGV] })->run();
+
+=head1 VERSION
+
+Version 0.4.5
+
+=head1 SUBROUTINES/METHODS
+
+=head2 new
+
+A constructor. Accepts the argv named arguments.
+
+=head2 run
+
+Runs the program.
+
 =head1 AUTHOR
 
 Shlomi Fish, L<http://www.shlomifish.org/>, C<< <shlomif at cpan.org> >> .
@@ -199,7 +210,6 @@ You can find documentation for this module with the perldoc command.
 
     perldoc App::Countdown
 
-
 You can also look for information at:
 
 =over 4
@@ -222,7 +232,6 @@ L<http://search.cpan.org/dist/App-Countdown/>
 
 =back
 
-
 =head1 ACKNOWLEDGEMENTS
 
 =over 4
@@ -261,7 +270,132 @@ WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2018 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/app-countdown/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Perldoc
+
+You can find documentation for this module with the perldoc command.
+
+  perldoc App::Countdown
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<https://metacpan.org/release/App-Countdown>
+
+=item *
+
+Search CPAN
+
+The default CPAN search engine, useful to view POD in HTML format.
+
+L<http://search.cpan.org/dist/App-Countdown>
+
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-Countdown>
+
+=item *
+
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
+
+L<http://annocpan.org/dist/App-Countdown>
+
+=item *
+
+CPAN Ratings
+
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
+L<http://cpanratings.perl.org/d/App-Countdown>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.cpanauthors.org/dist/App-Countdown>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/A/App-Countdown>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=App-Countdown>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=App::Countdown>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-app-countdown at rt.cpan.org>, or through
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=App-Countdown>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<https://github.com/shlomif/app-countdown>
+
+  git clone https://github.com/shlomif/App-Countdown
 
 =cut
-
-1; # End of App::Countdown
